# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementAgentPlugin(object):
    """
    Summary of the ManagementAgentPlugin.
    """

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentPlugin.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementAgentPlugin object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ManagementAgentPlugin.
        :type id: str

        :param name:
            The value to assign to the name property of this ManagementAgentPlugin.
        :type name: str

        :param version:
            The value to assign to the version property of this ManagementAgentPlugin.
        :type version: int

        :param supported_platform_types:
            The value to assign to the supported_platform_types property of this ManagementAgentPlugin.
        :type supported_platform_types: list[PlatformTypes]

        :param display_name:
            The value to assign to the display_name property of this ManagementAgentPlugin.
        :type display_name: str

        :param description:
            The value to assign to the description property of this ManagementAgentPlugin.
        :type description: str

        :param is_console_deployable:
            The value to assign to the is_console_deployable property of this ManagementAgentPlugin.
        :type is_console_deployable: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ManagementAgentPlugin.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'int',
            'supported_platform_types': 'list[PlatformTypes]',
            'display_name': 'str',
            'description': 'str',
            'is_console_deployable': 'bool',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'supported_platform_types': 'supportedPlatformTypes',
            'display_name': 'displayName',
            'description': 'description',
            'is_console_deployable': 'isConsoleDeployable',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._name = None
        self._version = None
        self._supported_platform_types = None
        self._display_name = None
        self._description = None
        self._is_console_deployable = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagementAgentPlugin.
        Management Agent Plugin Id


        :return: The id of this ManagementAgentPlugin.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagementAgentPlugin.
        Management Agent Plugin Id


        :param id: The id of this ManagementAgentPlugin.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ManagementAgentPlugin.
        Management Agent Plugin Name


        :return: The name of this ManagementAgentPlugin.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ManagementAgentPlugin.
        Management Agent Plugin Name


        :param name: The name of this ManagementAgentPlugin.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this ManagementAgentPlugin.
        Management Agent Plugin Version


        :return: The version of this ManagementAgentPlugin.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ManagementAgentPlugin.
        Management Agent Plugin Version


        :param version: The version of this ManagementAgentPlugin.
        :type: int
        """
        self._version = version

    @property
    def supported_platform_types(self):
        """
        Gets the supported_platform_types of this ManagementAgentPlugin.
        Supported Platform Types


        :return: The supported_platform_types of this ManagementAgentPlugin.
        :rtype: list[PlatformTypes]
        """
        return self._supported_platform_types

    @supported_platform_types.setter
    def supported_platform_types(self, supported_platform_types):
        """
        Sets the supported_platform_types of this ManagementAgentPlugin.
        Supported Platform Types


        :param supported_platform_types: The supported_platform_types of this ManagementAgentPlugin.
        :type: list[PlatformTypes]
        """
        self._supported_platform_types = supported_platform_types

    @property
    def display_name(self):
        """
        Gets the display_name of this ManagementAgentPlugin.
        Management Agent Plugin Display Name


        :return: The display_name of this ManagementAgentPlugin.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagementAgentPlugin.
        Management Agent Plugin Display Name


        :param display_name: The display_name of this ManagementAgentPlugin.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this ManagementAgentPlugin.
        Management Agent Plugin description


        :return: The description of this ManagementAgentPlugin.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ManagementAgentPlugin.
        Management Agent Plugin description


        :param description: The description of this ManagementAgentPlugin.
        :type: str
        """
        self._description = description

    @property
    def is_console_deployable(self):
        """
        Gets the is_console_deployable of this ManagementAgentPlugin.
        A flag to indicate whether a given plugin can be deployed from Agent Console UI or not.


        :return: The is_console_deployable of this ManagementAgentPlugin.
        :rtype: bool
        """
        return self._is_console_deployable

    @is_console_deployable.setter
    def is_console_deployable(self, is_console_deployable):
        """
        Sets the is_console_deployable of this ManagementAgentPlugin.
        A flag to indicate whether a given plugin can be deployed from Agent Console UI or not.


        :param is_console_deployable: The is_console_deployable of this ManagementAgentPlugin.
        :type: bool
        """
        self._is_console_deployable = is_console_deployable

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ManagementAgentPlugin.
        The current state of Management Agent Plugin

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this ManagementAgentPlugin.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ManagementAgentPlugin.
        The current state of Management Agent Plugin


        :param lifecycle_state: The lifecycle_state of this ManagementAgentPlugin.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CustomPropertyGetUsage(object):
    """
    Details of a single custom property
    """

    #: A constant which can be used with the data_type property of a CustomPropertyGetUsage.
    #: This constant has a value of "TEXT"
    DATA_TYPE_TEXT = "TEXT"

    #: A constant which can be used with the data_type property of a CustomPropertyGetUsage.
    #: This constant has a value of "RICH_TEXT"
    DATA_TYPE_RICH_TEXT = "RICH_TEXT"

    #: A constant which can be used with the data_type property of a CustomPropertyGetUsage.
    #: This constant has a value of "BOOLEAN"
    DATA_TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the data_type property of a CustomPropertyGetUsage.
    #: This constant has a value of "NUMBER"
    DATA_TYPE_NUMBER = "NUMBER"

    #: A constant which can be used with the data_type property of a CustomPropertyGetUsage.
    #: This constant has a value of "DATE"
    DATA_TYPE_DATE = "DATE"

    def __init__(self, **kwargs):
        """
        Initializes a new CustomPropertyGetUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CustomPropertyGetUsage.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this CustomPropertyGetUsage.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CustomPropertyGetUsage.
        :type description: str

        :param value:
            The value to assign to the value property of this CustomPropertyGetUsage.
        :type value: str

        :param data_type:
            The value to assign to the data_type property of this CustomPropertyGetUsage.
            Allowed values for this property are: "TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_type: str

        :param namespace_name:
            The value to assign to the namespace_name property of this CustomPropertyGetUsage.
        :type namespace_name: str

        :param namespace_key:
            The value to assign to the namespace_key property of this CustomPropertyGetUsage.
        :type namespace_key: str

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this CustomPropertyGetUsage.
        :type is_multi_valued: bool

        :param is_hidden:
            The value to assign to the is_hidden property of this CustomPropertyGetUsage.
        :type is_hidden: bool

        :param is_editable:
            The value to assign to the is_editable property of this CustomPropertyGetUsage.
        :type is_editable: bool

        :param is_list_type:
            The value to assign to the is_list_type property of this CustomPropertyGetUsage.
        :type is_list_type: bool

        :param allowed_values:
            The value to assign to the allowed_values property of this CustomPropertyGetUsage.
        :type allowed_values: list[str]

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'description': 'str',
            'value': 'str',
            'data_type': 'str',
            'namespace_name': 'str',
            'namespace_key': 'str',
            'is_multi_valued': 'bool',
            'is_hidden': 'bool',
            'is_editable': 'bool',
            'is_list_type': 'bool',
            'allowed_values': 'list[str]'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'description': 'description',
            'value': 'value',
            'data_type': 'dataType',
            'namespace_name': 'namespaceName',
            'namespace_key': 'namespaceKey',
            'is_multi_valued': 'isMultiValued',
            'is_hidden': 'isHidden',
            'is_editable': 'isEditable',
            'is_list_type': 'isListType',
            'allowed_values': 'allowedValues'
        }

        self._key = None
        self._display_name = None
        self._description = None
        self._value = None
        self._data_type = None
        self._namespace_name = None
        self._namespace_key = None
        self._is_multi_valued = None
        self._is_hidden = None
        self._is_editable = None
        self._is_list_type = None
        self._allowed_values = None

    @property
    def key(self):
        """
        Gets the key of this CustomPropertyGetUsage.
        Unique Identifier of the attribute which is ID


        :return: The key of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CustomPropertyGetUsage.
        Unique Identifier of the attribute which is ID


        :param key: The key of this CustomPropertyGetUsage.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this CustomPropertyGetUsage.
        Display name of the custom property


        :return: The display_name of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CustomPropertyGetUsage.
        Display name of the custom property


        :param display_name: The display_name of this CustomPropertyGetUsage.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CustomPropertyGetUsage.
        Description of the custom property


        :return: The description of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CustomPropertyGetUsage.
        Description of the custom property


        :param description: The description of this CustomPropertyGetUsage.
        :type: str
        """
        self._description = description

    @property
    def value(self):
        """
        Gets the value of this CustomPropertyGetUsage.
        The custom property value


        :return: The value of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this CustomPropertyGetUsage.
        The custom property value


        :param value: The value of this CustomPropertyGetUsage.
        :type: str
        """
        self._value = value

    @property
    def data_type(self):
        """
        Gets the data_type of this CustomPropertyGetUsage.
        The data type of the custom property

        Allowed values for this property are: "TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_type of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this CustomPropertyGetUsage.
        The data type of the custom property


        :param data_type: The data_type of this CustomPropertyGetUsage.
        :type: str
        """
        allowed_values = ["TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE"]
        if not value_allowed_none_or_none_sentinel(data_type, allowed_values):
            data_type = 'UNKNOWN_ENUM_VALUE'
        self._data_type = data_type

    @property
    def namespace_name(self):
        """
        Gets the namespace_name of this CustomPropertyGetUsage.
        Namespace name of the custom property


        :return: The namespace_name of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._namespace_name

    @namespace_name.setter
    def namespace_name(self, namespace_name):
        """
        Sets the namespace_name of this CustomPropertyGetUsage.
        Namespace name of the custom property


        :param namespace_name: The namespace_name of this CustomPropertyGetUsage.
        :type: str
        """
        self._namespace_name = namespace_name

    @property
    def namespace_key(self):
        """
        Gets the namespace_key of this CustomPropertyGetUsage.
        Unique namespace key that is immutable


        :return: The namespace_key of this CustomPropertyGetUsage.
        :rtype: str
        """
        return self._namespace_key

    @namespace_key.setter
    def namespace_key(self, namespace_key):
        """
        Sets the namespace_key of this CustomPropertyGetUsage.
        Unique namespace key that is immutable


        :param namespace_key: The namespace_key of this CustomPropertyGetUsage.
        :type: str
        """
        self._namespace_key = namespace_key

    @property
    def is_multi_valued(self):
        """
        Gets the is_multi_valued of this CustomPropertyGetUsage.
        If this field allows multiple values to be set


        :return: The is_multi_valued of this CustomPropertyGetUsage.
        :rtype: bool
        """
        return self._is_multi_valued

    @is_multi_valued.setter
    def is_multi_valued(self, is_multi_valued):
        """
        Sets the is_multi_valued of this CustomPropertyGetUsage.
        If this field allows multiple values to be set


        :param is_multi_valued: The is_multi_valued of this CustomPropertyGetUsage.
        :type: bool
        """
        self._is_multi_valued = is_multi_valued

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this CustomPropertyGetUsage.
        If this field is a hidden field


        :return: The is_hidden of this CustomPropertyGetUsage.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this CustomPropertyGetUsage.
        If this field is a hidden field


        :param is_hidden: The is_hidden of this CustomPropertyGetUsage.
        :type: bool
        """
        self._is_hidden = is_hidden

    @property
    def is_editable(self):
        """
        Gets the is_editable of this CustomPropertyGetUsage.
        If this field is a editable field


        :return: The is_editable of this CustomPropertyGetUsage.
        :rtype: bool
        """
        return self._is_editable

    @is_editable.setter
    def is_editable(self, is_editable):
        """
        Sets the is_editable of this CustomPropertyGetUsage.
        If this field is a editable field


        :param is_editable: The is_editable of this CustomPropertyGetUsage.
        :type: bool
        """
        self._is_editable = is_editable

    @property
    def is_list_type(self):
        """
        Gets the is_list_type of this CustomPropertyGetUsage.
        Is this property allowed to have list of values


        :return: The is_list_type of this CustomPropertyGetUsage.
        :rtype: bool
        """
        return self._is_list_type

    @is_list_type.setter
    def is_list_type(self, is_list_type):
        """
        Sets the is_list_type of this CustomPropertyGetUsage.
        Is this property allowed to have list of values


        :param is_list_type: The is_list_type of this CustomPropertyGetUsage.
        :type: bool
        """
        self._is_list_type = is_list_type

    @property
    def allowed_values(self):
        """
        Gets the allowed_values of this CustomPropertyGetUsage.
        Allowed values for the custom property if any


        :return: The allowed_values of this CustomPropertyGetUsage.
        :rtype: list[str]
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """
        Sets the allowed_values of this CustomPropertyGetUsage.
        Allowed values for the custom property if any


        :param allowed_values: The allowed_values of this CustomPropertyGetUsage.
        :type: list[str]
        """
        self._allowed_values = allowed_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateConnectionDetails(object):
    """
    Properties used in connection update operations.
    """

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "ORACLE_ADWC_CONNECTION"
    MODEL_TYPE_ORACLE_ADWC_CONNECTION = "ORACLE_ADWC_CONNECTION"

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "ORACLE_ATP_CONNECTION"
    MODEL_TYPE_ORACLE_ATP_CONNECTION = "ORACLE_ATP_CONNECTION"

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_CONNECTION"
    MODEL_TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = "ORACLE_OBJECT_STORAGE_CONNECTION"

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "ORACLEDB_CONNECTION"
    MODEL_TYPE_ORACLEDB_CONNECTION = "ORACLEDB_CONNECTION"

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "MYSQL_CONNECTION"
    MODEL_TYPE_MYSQL_CONNECTION = "MYSQL_CONNECTION"

    #: A constant which can be used with the model_type property of a UpdateConnectionDetails.
    #: This constant has a value of "GENERIC_JDBC_CONNECTION"
    MODEL_TYPE_GENERIC_JDBC_CONNECTION = "GENERIC_JDBC_CONNECTION"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateConnectionDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.UpdateConnectionFromJdbc`
        * :class:`~oci.data_integration.models.UpdateConnectionFromObjectStorage`
        * :class:`~oci.data_integration.models.UpdateConnectionFromAtp`
        * :class:`~oci.data_integration.models.UpdateConnectionFromOracle`
        * :class:`~oci.data_integration.models.UpdateConnectionFromAdwc`
        * :class:`~oci.data_integration.models.UpdateConnectionFromMySQL`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this UpdateConnectionDetails.
            Allowed values for this property are: "ORACLE_ADWC_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLEDB_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION"
        :type model_type: str

        :param key:
            The value to assign to the key property of this UpdateConnectionDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this UpdateConnectionDetails.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this UpdateConnectionDetails.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this UpdateConnectionDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateConnectionDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this UpdateConnectionDetails.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this UpdateConnectionDetails.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this UpdateConnectionDetails.
        :type identifier: str

        :param connection_properties:
            The value to assign to the connection_properties property of this UpdateConnectionDetails.
        :type connection_properties: list[ConnectionProperty]

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateConnectionDetails.
        :type registry_metadata: RegistryMetadata

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'connection_properties': 'list[ConnectionProperty]',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'connection_properties': 'connectionProperties',
            'registry_metadata': 'registryMetadata'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._connection_properties = None
        self._registry_metadata = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'GENERIC_JDBC_CONNECTION':
            return 'UpdateConnectionFromJdbc'

        if type == 'ORACLE_OBJECT_STORAGE_CONNECTION':
            return 'UpdateConnectionFromObjectStorage'

        if type == 'ORACLE_ATP_CONNECTION':
            return 'UpdateConnectionFromAtp'

        if type == 'ORACLEDB_CONNECTION':
            return 'UpdateConnectionFromOracle'

        if type == 'ORACLE_ADWC_CONNECTION':
            return 'UpdateConnectionFromAdwc'

        if type == 'MYSQL_CONNECTION':
            return 'UpdateConnectionFromMySQL'
        else:
            return 'UpdateConnectionDetails'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this UpdateConnectionDetails.
        The type of the connection.

        Allowed values for this property are: "ORACLE_ADWC_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLEDB_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION"


        :return: The model_type of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this UpdateConnectionDetails.
        The type of the connection.


        :param model_type: The model_type of this UpdateConnectionDetails.
        :type: str
        """
        allowed_values = ["ORACLE_ADWC_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLEDB_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    @property
    def key(self):
        """
        **[Required]** Gets the key of this UpdateConnectionDetails.
        Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.


        :return: The key of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this UpdateConnectionDetails.
        Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.


        :param key: The key of this UpdateConnectionDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateConnectionDetails.
        The model version of an object.


        :return: The model_version of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateConnectionDetails.
        The model version of an object.


        :param model_version: The model_version of this UpdateConnectionDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this UpdateConnectionDetails.

        :return: The parent_ref of this UpdateConnectionDetails.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this UpdateConnectionDetails.

        :param parent_ref: The parent_ref of this UpdateConnectionDetails.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this UpdateConnectionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateConnectionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateConnectionDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UpdateConnectionDetails.
        User-defined description for the connection.


        :return: The description of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateConnectionDetails.
        User-defined description for the connection.


        :param description: The description of this UpdateConnectionDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateConnectionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateConnectionDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateConnectionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateConnectionDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def object_version(self):
        """
        **[Required]** Gets the object_version of this UpdateConnectionDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this UpdateConnectionDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateConnectionDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this UpdateConnectionDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateConnectionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateConnectionDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateConnectionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateConnectionDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def connection_properties(self):
        """
        Gets the connection_properties of this UpdateConnectionDetails.
        The properties for the connection.


        :return: The connection_properties of this UpdateConnectionDetails.
        :rtype: list[ConnectionProperty]
        """
        return self._connection_properties

    @connection_properties.setter
    def connection_properties(self, connection_properties):
        """
        Sets the connection_properties of this UpdateConnectionDetails.
        The properties for the connection.


        :param connection_properties: The connection_properties of this UpdateConnectionDetails.
        :type: list[ConnectionProperty]
        """
        self._connection_properties = connection_properties

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateConnectionDetails.

        :return: The registry_metadata of this UpdateConnectionDetails.
        :rtype: RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateConnectionDetails.

        :param registry_metadata: The registry_metadata of this UpdateConnectionDetails.
        :type: RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .key_store_type_details import KeyStoreTypeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyStoreTypeFromOracleKeyVaultDetails(KeyStoreTypeDetails):
    """
    Details for Oracle Key Vault
    """

    def __init__(self, **kwargs):
        """
        Initializes a new KeyStoreTypeFromOracleKeyVaultDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.KeyStoreTypeFromOracleKeyVaultDetails.type` attribute
        of this class is ``ORACLE_KEY_VAULT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this KeyStoreTypeFromOracleKeyVaultDetails.
            Allowed values for this property are: "ORACLE_KEY_VAULT"
        :type type: str

        :param connection_ips:
            The value to assign to the connection_ips property of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type connection_ips: list[str]

        :param admin_username:
            The value to assign to the admin_username property of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type admin_username: str

        :param vault_id:
            The value to assign to the vault_id property of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type vault_id: str

        :param secret_id:
            The value to assign to the secret_id property of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type secret_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'connection_ips': 'list[str]',
            'admin_username': 'str',
            'vault_id': 'str',
            'secret_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'connection_ips': 'connectionIps',
            'admin_username': 'adminUsername',
            'vault_id': 'vaultId',
            'secret_id': 'secretId'
        }

        self._type = None
        self._connection_ips = None
        self._admin_username = None
        self._vault_id = None
        self._secret_id = None
        self._type = 'ORACLE_KEY_VAULT'

    @property
    def connection_ips(self):
        """
        **[Required]** Gets the connection_ips of this KeyStoreTypeFromOracleKeyVaultDetails.
        The list of Oracle Key Vault connection IP addresses.


        :return: The connection_ips of this KeyStoreTypeFromOracleKeyVaultDetails.
        :rtype: list[str]
        """
        return self._connection_ips

    @connection_ips.setter
    def connection_ips(self, connection_ips):
        """
        Sets the connection_ips of this KeyStoreTypeFromOracleKeyVaultDetails.
        The list of Oracle Key Vault connection IP addresses.


        :param connection_ips: The connection_ips of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type: list[str]
        """
        self._connection_ips = connection_ips

    @property
    def admin_username(self):
        """
        **[Required]** Gets the admin_username of this KeyStoreTypeFromOracleKeyVaultDetails.
        The administrator username to connect to Oracle Key Vault


        :return: The admin_username of this KeyStoreTypeFromOracleKeyVaultDetails.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this KeyStoreTypeFromOracleKeyVaultDetails.
        The administrator username to connect to Oracle Key Vault


        :param admin_username: The admin_username of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def vault_id(self):
        """
        **[Required]** Gets the vault_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The vault_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param vault_id: The vault_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def secret_id(self):
        """
        **[Required]** Gets the secret_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `secret`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The secret_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """
        Sets the secret_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        The `OCID`__ of the Oracle Cloud Infrastructure `secret`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param secret_id: The secret_id of this KeyStoreTypeFromOracleKeyVaultDetails.
        :type: str
        """
        self._secret_id = secret_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
